/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

trimInput = function(value) {
	return value.replace(/^\s*|\s*$/g, '');
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */

var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		/**
		 * Declaramos los eventos de los simbolos
		 */
		activeSymbols: function(e){
			$('.symbol').off('click').on('click', function(event) {
				/* Act on the event */
				event.preventDefault();

				//vars
				var $symbol = $(this),
					$parent = $symbol.parent(),
					$parents = $parent.parents('.island-wrapper'),
					$title  = $parent.parent().find('.symbol-title'),
				    $lines  = $parent.find('.symbol-lines'),
				    $icons  = $parent.find('.icon'),
				    $text   = $parent.parent().find('.symbol-text');

				var name = $symbol.data('name');

				if($parent.hasClass('active')){
				 		siteHandler.playLines(name,-1);
				}else{
				 	//add class active to see the picture without grayscale
				    $parent.addClass('active');
				    //remove class collapsed to increase the height of the div using padding-top
				    $parents.find('.symbol-wrapper').removeClass('collapsed');
				    $parents.find('.island-logo').removeClass('collapsed');
					//obtain data name to know which lines we are showing
					siteHandler.playLines(name);
				}
			});
		},
		/**
		 * Activa los eventos de los iconos de cada simbolo
		 *
		 * @param  {Array}   icons   - Array de jQuery con los iconos del simbolo correspondiente
		 *
		 */
		activeIcons: function(icons){
			$icons = icons;
			$icons.find('.inactive').off('click').on('click', function(event) {
				/* Act on the event */
				var area = $(this).parent().data('area');
				$(this).parents('.symbol-pictures').find('.' + area).addClass('flash').show();
				$(this).hide();
			});
			$icons.find('img').off('click').on('click', function(event) {
				/* Act on the event */
				var area = $(this).parent().data('area');
				$(this).parents('.symbol-pictures').find('.' + area).removeClass('flash').hide();
				$(this).parent().find('.inactive').show();
			});
		},
		activeLegend: function() {
			$('#curtainIcon').on('click', function(event) {
				event.preventDefault();
				$(this).find('i').toggleClass('fa-search-plus fa-search-minus');
				/* Act on the event */
				$('.legend-wrapper').toggleClass('closed');
			});
			$('#infoIcon').on('click', function(event) {
		       event.preventDefault();
		       event.stopPropagation();
		       /* Act on the event */
		       siteHandler.loadTemplate($(this).data('modal'),'#nucleusModal .modal-body');
		        $('#nucleusModal').modal();
		    });
		}
	},
	/**
	 * Declara los constructores de Vivus con variables globales
	 */
	prepareLines: function(){
		canario = new Vivus('canario', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.all-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		palmera = new Vivus('palmera', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.all-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		lagarto = new Vivus('lagarto', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.hi-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		sabina = new Vivus('sabina', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.hi-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		paloma = new Vivus('paloma', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.go-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		vinatigo = new Vivus('vinatigo', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.go-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		graja = new Vivus('graja', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.lp-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		pino = new Vivus('pino', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.lp-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		pinzon = new Vivus('pinzon', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.tf-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		drago = new Vivus('drago', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.tf-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		presa = new Vivus('presa', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.gc-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		cardon = new Vivus('cardon', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.gc-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		hubara = new Vivus('hubara', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.fv-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		cardonJandia = new Vivus('cardon-jandia', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.fv-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});

		cangrejo = new Vivus('cangrejo', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.lz-wrapper .left-wrapper');
			siteHandler.lineas($this,param);
		});

		tabaiba = new Vivus('tabaiba', {type: 'async', duration: 50, start: 'manual'}, function(param){
			var $this  = $('.lz-wrapper .right-wrapper');
			siteHandler.lineas($this,param);
		});
	},
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del simbolo para activar sus lineas
	 */
	playLines: function(name, speed){
		switch (name){
			case 'canario':
				speed ? canario.play(speed) : canario.play();
				break;
			case 'palmera':
				speed ? palmera.play(speed) : palmera.play();
				break;
			case 'lagarto':
				speed ? lagarto.play(speed) : lagarto.play();
				break;
			case 'sabina':
				speed ? sabina.play(speed) : sabina.play();
				break;
			case 'paloma':
				speed ? paloma.play(speed) : paloma.play();
				break;
			case 'vinatigo':
				speed ? vinatigo.play(speed) : vinatigo.play();
				break;
			case 'graja':
				speed ? graja.play(speed) : graja.play();
				break;
			case 'pino':
				speed ? pino.play(speed) : pino.play();
				break;
			case 'pinzon':
				speed ? pinzon.play(speed) : pinzon.play();
				break;
			case 'drago':
				speed ? drago.play(speed) : drago.play();
				break;
			case 'presa':
				speed ? presa.play(speed) : presa.play();
				break;
			case 'cardon':
				speed ? cardon.play(speed) : cardon.play();
				break;
			case 'hubara':
				speed ? hubara.play(speed) : hubara.play();
				break;
			case 'cardon-jandia':
				speed ? cardonJandia.play(speed) : cardonJandia.play();
				break;
			case 'cangrejo':
				speed ? cangrejo.play(speed) : cangrejo.play();
				break;
			case 'tabaiba':
				speed ? tabaiba.play(speed) : tabaiba.play();
				break;
			default:
		}
	},
	lineas: function($this,param)
	{
		var $icons = $this.find('.icon'),
		$title = $this.find('.symbol-title'),
		$titleH1 = $title.find('h1'),
		$titleH2 = $title.find('h2'),
		$text  = $this.find('.symbol-text'),
		$parent = $this.parent();

		if(param.speed !=-1){
			$this.find('.dot').attr('class','dot animated flash').show();
			$icons.removeClass('zoomOut').addClass('zoomIn').show();
			$titleH1.removeClass('fadeOutUp').addClass('fadeIn');
			$titleH2.removeClass('fadeOutUp').addClass('fadeInUp');;
			$title.show();
			$text.removeClass('fadeOut').addClass('fadeIn').show();
			siteHandler.setEvents.activeIcons($icons);
		}else{
			$this.find('.dot').attr('class','dot animated flash').hide();
			$this.find('.area').hide();
			$this.find('.inactive').show();
			$icons.removeClass('zoomIn').addClass('zoomOut');
			setTimeout(function() { // Delay (improve animation)
				$titleH1.removeClass('fadeIn').addClass('fadeOutUp');
				$titleH2.removeClass('fadeInUp').addClass('fadeOutUp');
				$text.find('p').animate({ opacity: 0 }, function(){
					$text.hide()
					$text.find('p').css('opacity','1');
				});
				$this.find('.symbol-pictures').removeClass('active');
				if(!$parent.find('.symbol-pictures').hasClass('active')){
					$parent.find('.symbol-wrapper').addClass('collapsed');
					$parent.find('.island-logo').addClass('collapsed');
				}
			}, 200);
		}
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activeSymbols();
			siteHandler.prepareLines();
			siteHandler.setEvents.activeLegend();
		});
	}
};

siteHandler.init();
